summaryrefslogtreecommitdiff
path: root/src/theory/output_channel.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/theory/output_channel.h')
-rw-r--r--src/theory/output_channel.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/theory/output_channel.h b/src/theory/output_channel.h
index 8c10a1348..16fc5a483 100644
--- a/src/theory/output_channel.h
+++ b/src/theory/output_channel.h
@@ -22,7 +22,7 @@
#include "theory/trust_node.h"
#include "util/resource_manager.h"
-namespace CVC4 {
+namespace CVC5 {
namespace theory {
/** Properties of lemmas */
@@ -66,7 +66,7 @@ class Theory;
/**
* Generic "theory output channel" interface.
*
* All methods can throw unrecoverable CVC4::Exception's unless otherwise
* documented.
*/
class OutputChannel {
@@ -199,6 +199,6 @@ class OutputChannel {
}; /* class OutputChannel */
} // namespace theory
-} // namespace CVC4
+} // namespace CVC5
#endif /* CVC4__THEORY__OUTPUT_CHANNEL_H */
generated by cgit on debian on lair
contact matthew@masot.net with questions or feedback
@@ -66,7 +66,7 @@ class Theory;
* Generic "theory output channel" interface.
*
- * All methods can throw unrecoverable CVC4::Exception's unless otherwise
+ * All methods can throw unrecoverable CVC5::Exception's unless otherwise
* documented.
*/